<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>ཡིག་གཟུགས་ཚང་མ།</translation>
    </message>
    <message>
        <source>System</source>
        <translation>མ་ལག་ཡིག་གཟུགས།</translation>
    </message>
    <message>
        <source>User</source>
        <translation>སྤྱོད་མཁན་གྱི་ཡིག་གཟུགས།</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>ངའི་ཉར་ཚགས།</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>སྐུལ་སློང་བྱས་ཟིན།</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>རྒྱ་ཡིག་ཡིག་གཟུགས།</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>ཞེང་མཚུངས་ཡིག་གཟུགས།</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>འདོར་བ།</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1ནི་ཡིག་གཟུགས་ཚོགས་པ་ཞིག་ཡིན་པས་དེ་བསུབ་ཚེ་དེའི་ཁོངས་གཏོགས་ཀྱི་ཡིག་གཟུགས་ཚང་མ་བསུབ་སྲིད།</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>ཡིག་གཟུགས་སུབ་པ།</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1ནི་ཡིག་གཟུགས་ཚོགས་པ་ཞིག་ཡིན་པས་དེ་འགོ་བསླང་ཚེ་དེའི་ཁོངས་གཏོགས་ཀྱི་ཡིག་གཟུགས་ཚང་མ་འགོ་སློང་སྲིད།</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1ནི་ཡིག་གཟུགས་ཚོགས་པ་ཞིག་ཡིན་པས་དེ་བཀོལ་མི་ཆོག་པ་བཟོས་ཚེ་དེའི་ཁོངས་གཏོགས་ཀྱི་ཡིག་གཟུགས་ཚང་མ་བཀོལ་མི་ཆོག</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>ཡིག་གཟུགས་སྤྱོད་འགོ་ཚུགས་པ།</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>ཡིག་གཟུགས་སྤྱོད་མི་ཆོག</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>བདམས་ཡོད་པའི་ཡིག་གཟུགས་ཚང་མར་སྤྱོད་པ།</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>འདོར་བ།</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>ཡིག་ཆ་སྐྱོན་ཤོར་ཟིན།</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>པར་གཞི་གཅིག་པ་སྒྲིག་སྦྱོར་བྱས་ཟིན།</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>མ་ལག་ཡིག་གཟུགས།</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>ཡིག་གཟུགས་%1སྒྲིག་སྦྱོར་བྱས་ཟིན།</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>ཡིག་གཟུགས་%1སྒྲིག་སྦྱོར་བྱས་ཟིན།</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>སུབ་རྗེས་ཡིག་གཟུགས་འདི་ཉེར་སྤྱོད་བྱ་རིམ་གཞན་ལ་སྤྱོད་མི་ཆོག</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>སུབ་རྗེས་ཡིག་གཟུགས་འདི་དག་ཉེར་སྤྱོད་བྱ་རིམ་གཞན་དག་ལ་སྤྱོད་མི་ཆོག</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>མ་ལག་ཡིག་གཟུགས་གཞན་དག་%1སུབ་ཐབས་མེད།</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>ད་ལྟ་སྤྱོད་བཞིན་པའི་ཡིག་གཟུགས་%1སུབ་ཐབས་མེད།</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>མ་ལག་ཡིག་གཟུགས་གཞན་དག་%1དང་སྤྱོད་བཞིན་པའི་ཡིག་གཟུགས་%2སུབ་ཐབས་མེད།</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>ཁྱེད་ཀྱིས་ཡིག་གཟུགས%1འདི་དག་སུབ་རྒྱུ་གཏན་འཁེལ་(ལམ)། </translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>ཡིག་གཟུགས་སུབ་པ།</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>ཡིག་གཟུགས་སུབ་བཞིན་ཡོད་པས། སྒུག་རོགས་གནང་།</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>ཡིག་གཟུགས་ར་སྤྲོད།</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>སྒྲིག་སྦྱོར་བྱེད་རུང་བའི་ཡིག་གཟུགས་མེད།</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>ཕྱིར་འབུད།</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>མུ་མཐུད།</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>གཞི་རྩའི་ཆ་འཕྲིན།</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>དཔེ་དབྱིབས།</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>རིགས་གྲས།</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>པར་གཞི།</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>ཞིབ་བརྗོད།</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>མི་ཤེས།</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>མིང་ཆ་ཚང་།</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>PSམིང་།</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>ཚོང་རྟགས།</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>ཡིག་གཟུགས་དོ་དམ་ཆས།</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>ཡིག་གཟུགས་དོ་དམ་ཆས་ནི་སྤྱོད་མཁན་གྱི་ཡིག་གཟུགས་སྒྲིག་སྦྱོར་དང་དོ་དམ་ལ་རོགས་རམ་བྱེད་པའི་ཡོ་བྱད་ཅིག་རེད།</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>ཡིག་གཟུགས་འཇུག་བཞིན་ཡོད་པས། སྒུག་རོགས་གནང་།</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>ཡིག་གཟུགས་འདི་ཅོག་ངོས་སུ་ཕྱིར་འདྲེན་བྱས་ཟིན།</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>ཡིག་གཟུགས་%1ཅོག་ངོས་སུ་ཕྱིར་འདྲེན་བྱས་ཟིན།</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>དམིགས་འབེན་སྡུད་སྡེར་གྱི་བར་སྟོང་མི་ལྡང་བས། ཡིག་ཆ་1ཕྱིར་འདྲེན་བྱེད་མི་ཐུབ།</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>དམིགས་འབེན་སྡུད་སྡེར་གྱི་བར་སྟོང་མི་ལྡང་བས། ཡིག་ཆ་%1ཕྱིར་འདྲེན་བྱེད་མི་ཐུབ།</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>ཡིག་གཟུགས་སྣོན་པ།</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>ཡིག་གཟུགས་སྤྱོད་འགོ་ཚུགས་པ།</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>ཡིག་གཟུགས་སྤྱོད་མི་ཆོག</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ཡིག་གཟུགས་སུབ་པ།</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>ཉར་ཚགས།</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>ཉར་ཚགས་མི་བྱེད།</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>ཆ་འཕྲིན།</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>ཡིག་ཆ་དོ་དམ་ཆས་ཁྲོད་དུ་འཆར་བ།</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>ཡིག་གཟུགས་ཕྱིར་འདྲེན་པ།</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>སྤྱོད་མི་ཆོག</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>ཡིག་གཟུགས་སྤྱོད་མི་ཆོག</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1སྤྱོད་བཞིན་ཡོད་པས། སྤྱོད་མི་ཆོག་པ་བཟོ་ཐབས་མེད།</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>མ་ལག་ཡིག་གཟུགས་དང་སྤྱོད་བཞིན་པའི་ཡིག་གཟུགས་སྤྱོད་མི་ཆོག་པ་བཟོ་ཐབས་མེད།</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>མ་ལག་ཡིག་གཟུགས་སྤྱོད་མི་ཆོག་པ་བཟོ་ཐབས་མེད།</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>ཡིག་གཟུགས་སྒྲིག་སྦྱོར།</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>ར་སྤྲོད་བཞིན་པ།</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>མི་ཤེས།</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>ཡིག་ཆ་སྐྱོན་ཤོར་ཟིན།</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>སྒྲིག་སྦྱོར་བྱས་ཟིན།</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>སྒྲིག་སྦྱོར་བྱས་མེད།</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>ཡིག་གཟུགས་སྒྲིག་སྦྱོར།</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>འཚོལ་ཞིབ།</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>འཚོལ་ཞིབ་བྱས་འབྲས་མེད།</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>ཡིག་གཟུགས་མེད།</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>རོགས་པ།</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>མྱུར་མཐེབ་འཆར་བ།</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>ཤོག་ངོས་གོང་མ།</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>ཤོག་ངོས་རྗེས་མ།</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>སུབ་པ།</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>ཡིག་གཟུགས་སྣོན་པ།</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>ཉར་ཚགས།</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>ཉར་ཚགས་མི་བྱེད།</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>ཡིག་གཟུགས་ཆ་འཕྲིན།</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>ཡིག་ཆའི་ནང་དོན་འཇུག་ནས་སྔོན་འཆར་བྱེད་པ།</translation>
    </message>
</context>
</TS>